colour_hdri.plotting.radiance Module — Colour - HDRI 0.1.0 documentation

# colour_hdri.plotting.radiance Module

## HDRI / Radiance Image Plotting

Defines the HDRI / radiance image plotting objects:

- `radiance_image_strip_plot()`

`colour_hdri.plotting.radiance.` `radiance_image_strip_plot`(image, count=5, ev_steps=-2, transfer_function=<function _srgb_transfer_function at 0x1092570c8>)

  Plots given HDRI / radiance image as strip of images of varying exposure.

  Parameters: | image (array_like) – HDRI / radiance image to plot. count (int, optional) – Strip images count. ev_steps (numeric, optional) – Exposure variation for each image of the strip. transfer_function (callable, optional) – OECF / transfer function used for plotting.
  Returns: | Definition success.
  Return type: | bool